# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['dbustiker']
install_requires = \
['vk-api>=11.9.1,<12.0.0']

setup_kwargs = {
    'name': 'dbustiker',
    'version': '1.0.0',
    'description': 'Получение наборов стикеров которые есть у других пользователей вк их ценну в рублях и голосах.',
    'long_description': None,
    'author': 'Сергей Бухтояров',
    'author_email': 'darsox.anime@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



import json
import requests


def get_stiket(ID):
    try:
        if int(ID) > 0:
            gets = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_stiker&id={}'.format(ID)).json()
            return gets
        else:
            'DBU_EROR: user_id должен быть больше 0'
    except Exception as e:
        print(e)
        return 'DBU_EROR: user_id должен быть числом.'

def get_keys(txt = ''):
    gets = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_genetator&text={}'.format(str(txt))).json()
    return gets

def get_short(urls = ''):
    gets = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_shortlink&url={}'.format(str(urls))).json()
    return gets

def get_check(urls = ''):
    gets = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_check_link&url={}'.format(str(urls))).json()
    return gets

def get_trans_emj(text = 'котик в воде'):
    gets = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_emoji_transl&text={}'.format(str(text).lower())).json()
    return gets

def get_stiket_info(ID,tokens = ''):
    try:
        if int(ID) > 0:
            if tokens != '':
                getd = requests.get('https://paladinbot.pythonanywhere.com/dbu/?method=get_stiker_info&id={}&token={}'.format(ID,tokens)).json()
                return getd
            else:
                return 'DBU_EROR: Второй параметр, должен быть ваш Токен!Так как mess_id для каждого пользователя разный.'
        else:
            'DBU_EROR: packs_id должен быть больше 0'
    except Exception as e:
        return 'DBU_EROR: packs_id должен быть числом.'
